@@ -112,9 +112,10 @@ static void* get_event(void *unused)
                         rptentry.ResourceId = 0;
 			memset(&event, 0xF, sizeof(event));
 			rv = saHpiEventGet(Domain->sessionId,
-				SAHPI_TIMEOUT_IMMEDIATE, &event,
-				NULL, NULL, NULL);		
+				SAHPI_TIMEOUT_BLOCK, &event,
+				&rdr, &rptentry, NULL);		
 			if (rv != SA_OK ) {
+				printf("saHpiEventGet failed with error <%d>", rv);
 				break;
 			}
 			if (prt_flag == 1) {
@@ -132,9 +133,6 @@ static void* get_event(void *unused)
                                         if(rv == SA_OK)
                                                 oh_print_event(&event, &rptentry.ResourceEntity, 4);
                                         else {
-                                                printf("saHpiRptEntryGet failed for resource Id <%d> with error <%d>",
-                                                        event.Source, rv);
-                                                printf("Wrong resource Id <%d> detected", event.Source);
                                                 oh_print_event(&event, NULL, 4);
                                         }
                                 }
@@ -263,7 +261,8 @@ int close_session()
 {
 	SaErrorT rv;
 
-	pthread_kill(ge_thread, SIGKILL);
+	/* Bug 2171901, replace pthread_kill(ge_thread, SIGKILL); */
+	pthread_cancel(ge_thread);
 	
 	rv = saHpiSessionClose(Domain->sessionId);
 	if (rv != SA_OK) {
