@@ -15,6 +15,7 @@
  *     Sean Dague <http://dague.net/sean>
  *     Renier Morales <renier@openhpi.org>
  *     Racing Guo <racing.guo@intel.com>
+ *     Anton Pak <anton.pak@pigeonpoint.com>
  */
 
 #ifndef __OH_HANDLER_H
@@ -214,6 +215,11 @@ struct oh_abi_v2 {
         SaErrorT (*set_resource_severity)(void *hnd,
 					  SaHpiResourceIdT id,
 					  SaHpiSeverityT sev);
+        /***
+         * saHpiResourceFailedRemove, passed down to plugin
+         **/
+	SaErrorT (*resource_failed_remove)(void *hnd,
+					   SaHpiResourceIdT rid);
 
         /*****************
          * EVENT LOG ABIs
@@ -638,6 +644,24 @@ struct oh_abi_v2 {
          * FUMI ABIs
          ***************/
 
+        /***
+         * saHpiFumiSpecInfoGet 
+         **/
+        SaErrorT (*get_fumi_spec)(
+                                void *hnd,
+                                SaHpiResourceIdT id,
+                                SaHpiFumiNumT num,
+                                SaHpiFumiSpecInfoT *specinfo );
+
+        /***
+         * saHpiFumiServiceImpactGet
+         **/
+        SaErrorT (*get_fumi_service_impact)(
+                                void *hnd,
+                                SaHpiResourceIdT id,
+                                SaHpiFumiNumT num,
+                                SaHpiFumiServiceImpactDataT *serviceimpact );
+
         /***
          * saHpiFumiSourceSet
          **/
@@ -667,6 +691,18 @@ struct oh_abi_v2 {
                                 SaHpiBankNumT banknum,
                                 SaHpiFumiSourceInfoT *sourceinfo);
 
+        /***
+         * saHpiFumiSourceComponentInfoGet
+         **/
+        SaErrorT (*get_fumi_source_component)(
+                                void *hnd,
+                                SaHpiResourceIdT id,
+                                SaHpiFumiNumT num,
+                                SaHpiBankNumT banknum,
+                                SaHpiEntryIdT compid,
+                                SaHpiEntryIdT *nextcompid,
+                                SaHpiFumiComponentInfoT *compinfo);
+
         /***
          * saHpiFumiTargetInfoGet
          **/
@@ -677,6 +713,38 @@ struct oh_abi_v2 {
                                 SaHpiBankNumT banknum,
                                 SaHpiFumiBankInfoT *bankinfo);
 
+        /***
+         * saHpiFumiTargetComponentInfoGet
+         **/
+        SaErrorT (*get_fumi_target_component)(
+                                void *hnd,
+                                SaHpiResourceIdT id,
+                                SaHpiFumiNumT num,
+                                SaHpiBankNumT banknum,
+                                SaHpiEntryIdT compid,
+                                SaHpiEntryIdT *nextcompid,
+                                SaHpiFumiComponentInfoT *compinfo);
+
+        /***
+         * saHpiFumiLogicalTargetInfoGet
+         **/
+        SaErrorT (*get_fumi_logical_target)(
+                                void *hnd,
+                                SaHpiResourceIdT id,
+                                SaHpiFumiNumT num,
+                                SaHpiFumiLogicalBankInfoT *bankinfo);
+
+        /***
+         * saHpiFumiLogicalTargetComponentInfoGet
+         **/
+        SaErrorT (*get_fumi_logical_target_component)(
+                                void *hnd,
+                                SaHpiResourceIdT id,
+                                SaHpiFumiNumT num,
+                                SaHpiEntryIdT compid,
+                                SaHpiEntryIdT *nextcompid,
+                                SaHpiFumiLogicalComponentInfoT *compinfo);
+
         /***
          * saHpiFumiBackupStart
          **/
@@ -733,6 +801,14 @@ struct oh_abi_v2 {
                                 SaHpiFumiNumT num,
                                 SaHpiBankNumT banknum);
 
+        /***
+         * saHpiFumiTargetVerifyMainStart
+         **/
+        SaErrorT (*start_fumi_verify_main)(
+                                void *hnd,
+                                SaHpiResourceIdT id,
+                                SaHpiFumiNumT num );
+
         /***
          * saHpiFumiUpgradeCancel
          **/
@@ -742,6 +818,24 @@ struct oh_abi_v2 {
                                 SaHpiFumiNumT num,
                                 SaHpiBankNumT banknum);
 
+        /***
+         * saHpiFumiAutoRollbackDisableGet
+         **/
+        SaErrorT (*get_fumi_autorollback_disable)(
+                                void *hnd,
+                                SaHpiResourceIdT id,
+                                SaHpiFumiNumT num,
+                                SaHpiBoolT *disable);
+
+        /***
+         * saHpiFumiAutoRollbackDisableSet
+         **/
+        SaErrorT (*set_fumi_autorollback_disable)(
+                                void *hnd,
+                                SaHpiResourceIdT id,
+                                SaHpiFumiNumT num,
+                                SaHpiBoolT disable);
+
         /***
          * saHpiFumiRollback
          **/
@@ -757,6 +851,23 @@ struct oh_abi_v2 {
                                 void *hnd,
                                 SaHpiResourceIdT id,
                                 SaHpiFumiNumT num);
+        /***
+         * saHpiFumiActivateStart
+         **/
+        SaErrorT (*start_fumi_activate)(
+                                void *hnd,
+                                SaHpiResourceIdT id,
+                                SaHpiFumiNumT num,
+                                SaHpiBoolT logical);
+
+        /***
+         * saHpiFumiCleanup
+         **/
+        SaErrorT (*cleanup_fumi)(
+                                void *hnd,
+                                SaHpiResourceIdT id,
+                                SaHpiFumiNumT num,
+                                SaHpiBankNumT banknum);
         
 	/***************
 	 * HOTSWAP ABIs
