@@ -14,6 +14,7 @@
  *     Thomas Kanngieser <thomas.kanngieser@fci.com>
  *     W. David Ashley <dashley@us.ibm.com.com>
  *     Renier Morales <renier@openhpi.org>
+ *     Anton Pak <anton.pak@pigeonpoint.com>
  */
 
 #include "marshal_hpi.h"
@@ -171,6 +172,20 @@ static const cMarshalType *saHpiResourceTagSetOut[] =
 };
 
 
+static const cMarshalType *saHpiMyEntityPathGetIn[] =
+{
+  &SaHpiSessionIdType, // session id (SaHpiSessionIdT)
+  0
+};
+
+static const cMarshalType *saHpiMyEntityPathGetOut[] =
+{
+  &SaErrorType, // result (SaErrorT)
+  &SaHpiEntityPathType,
+  0
+};
+
+
 static const cMarshalType *saHpiResourceIdGetIn[] =
 {
   &SaHpiSessionIdType, // session id (SaHpiSessionIdT)
@@ -559,6 +574,21 @@ static const cMarshalType *saHpiRdrGetByInstrumentIdOut[] =
 };
 
 
+static const cMarshalType *saHpiRdrUpdateCountGetIn[] =
+{
+  &SaHpiSessionIdType, // session id (SaHpiSessionIdT)
+  &SaHpiResourceIdType,
+  0
+};
+
+static const cMarshalType *saHpiRdrUpdateCountGetOut[] =
+{
+  &SaErrorType, // result (SaErrorT)
+  &SaHpiUint32Type,
+  0
+};
+
+
 static const cMarshalType *saHpiSensorReadingGetIn[] =
 {
   &SaHpiSessionIdType, // session id (SaHpiSessionIdT)
@@ -1224,6 +1254,34 @@ static const cMarshalType *saHpiDimiTestResultsGetOut[] =
 };
 
 // FUMIs
+static const cMarshalType *saHpiFumiSpecInfoGetIn[]=
+{
+        &SaHpiSessionIdType,
+        &SaHpiResourceIdType,
+        &SaHpiFumiNumType,
+        0
+};
+static const cMarshalType *saHpiFumiSpecInfoGetOut[] =
+{
+        &SaErrorType,
+        &SaHpiFumiSpecInfoType,
+        0
+};
+
+static const cMarshalType *saHpiFumiServiceImpactGetIn[]=
+{
+        &SaHpiSessionIdType,
+        &SaHpiResourceIdType,
+        &SaHpiFumiNumType,
+        0
+};
+static const cMarshalType *saHpiFumiServiceImpactGetOut[] =
+{
+        &SaErrorType,
+        &SaHpiFumiServiceImpactDataType,
+        0
+};
+
 static const cMarshalType *saHpiFumiSourceSetIn[]=
 {
         &SaHpiSessionIdType,
@@ -1268,6 +1326,23 @@ static const cMarshalType *saHpiFumiSourceInfoGetOut[] =
         0
 };
 
+static const cMarshalType *saHpiFumiSourceComponentInfoGetIn[]=
+{
+        &SaHpiSessionIdType,
+        &SaHpiResourceIdType,
+        &SaHpiFumiNumType,
+        &SaHpiBankNumType,
+        &SaHpiEntryIdType,
+        0
+};
+static const cMarshalType *saHpiFumiSourceComponentInfoGetOut[] =
+{
+        &SaErrorType,
+        &SaHpiEntryIdType,
+        &SaHpiFumiComponentInfoType,
+        0
+};
+
 static const cMarshalType *saHpiFumiTargetInfoGetIn[]=
 {
         &SaHpiSessionIdType,
@@ -1283,6 +1358,53 @@ static const cMarshalType *saHpiFumiTargetInfoGetOut[] =
         0
 };
 
+static const cMarshalType *saHpiFumiTargetComponentInfoGetIn[]=
+{
+        &SaHpiSessionIdType,
+        &SaHpiResourceIdType,
+        &SaHpiFumiNumType,
+        &SaHpiBankNumType,
+        &SaHpiEntryIdType,
+        0
+};
+static const cMarshalType *saHpiFumiTargetComponentInfoGetOut[] =
+{
+        &SaErrorType,
+        &SaHpiEntryIdType,
+        &SaHpiFumiComponentInfoType,
+        0
+};
+
+static const cMarshalType *saHpiFumiLogicalTargetInfoGetIn[]=
+{
+        &SaHpiSessionIdType,
+        &SaHpiResourceIdType,
+        &SaHpiFumiNumType,
+        0
+};
+static const cMarshalType *saHpiFumiLogicalTargetInfoGetOut[] =
+{
+        &SaErrorType,
+        &SaHpiFumiLogicalBankInfoType,
+        0
+};
+
+static const cMarshalType *saHpiFumiLogicalTargetComponentInfoGetIn[]=
+{
+        &SaHpiSessionIdType,
+        &SaHpiResourceIdType,
+        &SaHpiFumiNumType,
+        &SaHpiEntryIdType,
+        0
+};
+static const cMarshalType *saHpiFumiLogicalTargetComponentInfoGetOut[] =
+{
+        &SaErrorType,
+        &SaHpiEntryIdType,
+        &SaHpiFumiLogicalComponentInfoType,
+        0
+};
+
 static const cMarshalType *saHpiFumiBackupStartIn[]=
 {
         &SaHpiSessionIdType,
@@ -1369,6 +1491,21 @@ static const cMarshalType *saHpiFumiTargetVerifyStartOut[] =
         0
 };
 
+
+static const cMarshalType *saHpiFumiTargetVerifyMainStartIn[]=
+{
+        &SaHpiSessionIdType,
+        &SaHpiResourceIdType,
+        &SaHpiFumiNumType,
+        0
+};
+static const cMarshalType *saHpiFumiTargetVerifyMainStartOut[] =
+{
+        &SaErrorType,
+        0
+};
+
+
 static const cMarshalType *saHpiFumiUpgradeCancelIn[]=
 {
         &SaHpiSessionIdType,
@@ -1383,6 +1520,38 @@ static const cMarshalType *saHpiFumiUpgradeCancelOut[] =
         0
 };
 
+
+static const cMarshalType *saHpiFumiAutoRollbackDisableGetIn[] =
+{
+        &SaHpiSessionIdType,
+        &SaHpiResourceIdType,
+        &SaHpiFumiNumType,
+        0
+};
+static const cMarshalType *saHpiFumiAutoRollbackDisableGetOut[] =
+{
+        &SaErrorType,
+        &SaHpiBoolType,
+        0
+};
+
+
+static const cMarshalType *saHpiFumiAutoRollbackDisableSetIn[] =
+{
+        &SaHpiSessionIdType,
+        &SaHpiResourceIdType,
+        &SaHpiFumiNumType,
+        &SaHpiBoolType,
+        0
+};
+
+static const cMarshalType *saHpiFumiAutoRollbackDisableSetOut[] =
+{
+        &SaErrorType, // result (SaErrorT)
+        0
+};
+
+
 static const cMarshalType *saHpiFumiRollbackIn[]=
 {
         &SaHpiSessionIdType,
@@ -1410,6 +1579,36 @@ static const cMarshalType *saHpiFumiActivateOut[] =
 };
 
 
+static const cMarshalType *saHpiFumiActivateStartIn[]=
+{
+        &SaHpiSessionIdType,
+        &SaHpiResourceIdType,
+        &SaHpiFumiNumType,
+        &SaHpiBoolType,
+        0
+};
+static const cMarshalType *saHpiFumiActivateStartOut[] =
+{
+        &SaErrorType,
+        0
+};
+
+
+static const cMarshalType *saHpiFumiCleanupIn[]=
+{
+        &SaHpiSessionIdType,
+        &SaHpiResourceIdType,
+        &SaHpiFumiNumType,
+    	&SaHpiBankNumType,
+        0
+};
+static const cMarshalType *saHpiFumiCleanupOut[] =
+{
+        &SaErrorType,
+        0
+};
+
+
 // Hotswap
 static const cMarshalType *saHpiHotSwapPolicyCancelIn[] =
 {
@@ -1919,6 +2118,22 @@ static cHpiMarshal hpi_marshal[] =
   dHpiMarshalEntry( oHpiGlobalParamGet ),
   dHpiMarshalEntry( oHpiGlobalParamSet ),
   dHpiMarshalEntry( oHpiInjectEvent ),
+
+  // New B.03.01 functions
+  // They are added to the end of enum in order to keep ABI compatibility
+  dHpiMarshalEntry( saHpiMyEntityPathGet ),
+  dHpiMarshalEntry( saHpiRdrUpdateCountGet ),
+  dHpiMarshalEntry( saHpiFumiSpecInfoGet ),
+  dHpiMarshalEntry( saHpiFumiServiceImpactGet ),
+  dHpiMarshalEntry( saHpiFumiSourceComponentInfoGet ),
+  dHpiMarshalEntry( saHpiFumiTargetComponentInfoGet ),
+  dHpiMarshalEntry( saHpiFumiLogicalTargetInfoGet ),
+  dHpiMarshalEntry( saHpiFumiLogicalTargetComponentInfoGet ),
+  dHpiMarshalEntry( saHpiFumiTargetVerifyMainStart ),
+  dHpiMarshalEntry( saHpiFumiAutoRollbackDisableGet ),
+  dHpiMarshalEntry( saHpiFumiAutoRollbackDisableSet ),
+  dHpiMarshalEntry( saHpiFumiActivateStart ),
+  dHpiMarshalEntry( saHpiFumiCleanup ),
 };
 
 
