@@ -351,8 +351,8 @@ cIpmiMcVendor::FindResource( cIpmiDomain *domain, cIpmiMc *mc,
 {
   assert( mc );
 
-  SaHpiEntityTypeT     type;
-  SaHpiEntityLocationT instance;
+  SaHpiEntityTypeT     type = SAHPI_ENT_UNKNOWN;
+  SaHpiEntityLocationT instance = GetUniqueInstance();
 
   if ( sdr )
      {
@@ -370,11 +370,6 @@ cIpmiMcVendor::FindResource( cIpmiDomain *domain, cIpmiMc *mc,
        else
 	    assert( 0 );
      }
-  else
-     {
-       type = SAHPI_ENT_UNKNOWN;
-       instance = GetUniqueInstance();
-     }
   stdlog << "FindResource mc " << mc->GetAddress() << " FRU " << fru_id << " type " << type << " instance " << instance << "\n";
 
   cIpmiEntityPath ep = CreateEntityPath( domain, mc->GetAddress(), fru_id,
@@ -394,8 +389,8 @@ cIpmiMcVendor::FindOrCreateResource( cIpmiDomain *domain, cIpmiMc *mc,
 {
   assert( mc );
 
-  SaHpiEntityTypeT     type;
-  SaHpiEntityLocationT instance;
+  SaHpiEntityTypeT     type = SAHPI_ENT_UNKNOWN;
+  SaHpiEntityLocationT instance = GetUniqueInstance();
 
   if ( sdr )
      {
@@ -413,11 +408,6 @@ cIpmiMcVendor::FindOrCreateResource( cIpmiDomain *domain, cIpmiMc *mc,
        else
 	    assert( 0 );
      }
-  else
-     {
-       type = SAHPI_ENT_UNKNOWN;
-       instance = GetUniqueInstance();
-     }
   stdlog << "FindOrCreateResource mc " << mc->GetAddress() << " FRU " << fru_id << " type " << type << " instance " << instance << "\n";
 
   cIpmiEntityPath ep = CreateEntityPath( domain, mc->GetAddress(), fru_id,
@@ -441,8 +431,8 @@ cIpmiMcVendor::CreateResource( cIpmiDomain *domain, cIpmiMc *mc,
   // create a new resource
   cIpmiResource *res = new cIpmiResource( mc, fru_id );
 
-  SaHpiEntityTypeT     type;
-  SaHpiEntityLocationT instance;
+  SaHpiEntityTypeT     type = SAHPI_ENT_UNKNOWN;
+  SaHpiEntityLocationT instance = GetUniqueInstance();
 
   if ( sdr )
      {
@@ -460,11 +450,6 @@ cIpmiMcVendor::CreateResource( cIpmiDomain *domain, cIpmiMc *mc,
        else
 	    assert( 0 );
      }
-  else
-     {
-       type = SAHPI_ENT_UNKNOWN;
-       instance = GetUniqueInstance();
-     }
 
   res->EntityPath() = CreateEntityPath( domain, mc->GetAddress(), fru_id,
                                         type, instance, sdrs );
@@ -514,6 +499,44 @@ cIpmiMcVendor::CreateEntityPath( cIpmiDomain *domain, unsigned int mc_addr, unsi
   if ( instance >= 0x60 )
        instance -= 0x60;
 
+  switch (type)
+  {
+    default:
+        break;
+
+    case eIpmiEntityIdPicMgFrontBoard:
+        type = SaHpiEntityTypeT(ATCAHPI_ENT_PICMG_FRONT_BLADE);
+        break;
+
+    case eIpmiEntityIdPicMgRearTransitionModule:
+        type = SAHPI_ENT_BACK_PANEL_BOARD;
+        break;
+
+    case eIpmiEntityIdPicMgAdvancedMcModule:
+        type = SaHpiEntityTypeT(ATCAHPI_ENT_AMC);
+        break;
+
+    case eIpmiEntityIdPicMgMicroTcaCarrierHub:
+        type = SAHPI_ENT_SWITCH_BLADE;
+        break;
+
+    case eIpmiEntityIdPicmgShelfManager:
+        type = SAHPI_ENT_SHELF_MANAGER;
+        break;
+
+    case eIpmiEntityIdPicmgFiltrationUnit:
+        type = SaHpiEntityTypeT(ATCAHPI_ENT_FILTRATION_UNIT);
+        break;
+
+    case eIpmiEntityIdPicmgShelfFruInformation:
+        type = SaHpiEntityTypeT(ATCAHPI_ENT_SHELF_FRU_DEVICE);
+        break;
+
+    case eIpmiEntityIdPicmgAlarmPanel:
+        type = SAHPI_ENT_ALARM_MANAGER;
+        break;
+  }
+
   bottom.SetEntry( 0, type, instance );
   bottom.AppendRoot( 1 );
 
@@ -860,7 +883,7 @@ cIpmiMcVendor::CreateControls( cIpmiDomain *domain, cIpmiMc *source_mc,
   if ( source_mc == 0 )
        return true;
 
-  if ( source_mc->IsAtcaBoard() )
+  if ( source_mc->IsTcaMc() )
      {
        return CreateControlsAtca( domain, source_mc, sdrs );
      }
