@@ -31,6 +31,7 @@
  * Author(s)
  *      Raghavendra P.G. <raghavendra.pg@hp.com>
  *      Vivek Kumar <vivek.kumar2@hp.com>
+ *      Shuah Khan <shuah.khan@hp.com>
  *
  * This file implements all the utility functions which will be useful of oa
  * soap functioning. Majority of the functions are helper functions for
@@ -79,18 +80,12 @@
  *
  *      create_oa_connection()          - Create OA connection after closing the
  *                                        earlier soap_con structures
- *                                        
+ *
  *      initialize_oa_con()             - Initialize the hpi_con and event_con
- *      
+ *
  *      delete_all_inventory_info()     - Frees the memory allocated for
  *                                        inventory areas for all the resources
  *
- *      populate_event()                - Populates the event structure
- *
- *      push_discovered_resource_events - Creates the event structure.
- *                                        Pushes the discovered resource events
- *                                        to OpenHPI infrastructure
- *
  *      cleanup_plugin_rptable()        - Frees the memory allocated for
  *                                        plugin RPTable
  *
@@ -342,7 +337,7 @@ SaErrorT get_oa_state(struct oh_handler_state *oh_handler,
                 /* Find the active and standby bay number, IP address
                  * and firmware version */
                 switch (oa_role) {
-                        case ACTIVE :
+                        case ACTIVE:
                                 active_bay = i;
                                 memset(active_ip, 0, MAX_URL_LEN);
                                 strncpy(active_ip,
@@ -353,7 +348,7 @@ SaErrorT get_oa_state(struct oh_handler_state *oh_handler,
                                 memset(active_fm, 0, MAX_BUF_SIZE);
                                 strncpy(active_fm, firmware, strlen(firmware));
                                 break;
-                        case STANDBY :
+                        case STANDBY:
                                 standby_bay = i;
                                 memset(standby_ip, 0, MAX_URL_LEN);
                                 strncpy(standby_ip,
@@ -364,7 +359,7 @@ SaErrorT get_oa_state(struct oh_handler_state *oh_handler,
                                 memset(standby_fm, 0, MAX_BUF_SIZE);
                                 strncpy(standby_fm, firmware, strlen(firmware));
                                 break;
-                        default :
+                        default:
                                 err("wrong oa state detected for bay %d", i);
                                 soap_close(hpi_con);
                                 soap_close(event_con);
@@ -500,7 +495,6 @@ void update_hotswap_event(struct oh_handler_state *oh_handler,
         event->event.EventType = SAHPI_ET_HOTSWAP;
         /* TODO: map the timestamp of the OA generated event */
         oh_gettimeofday(&(event->event.Timestamp));
-        /* All the hotswap events raised by OA SOAP plug-in are critical */
         event->event.Severity = SAHPI_CRITICAL;
 }
 
@@ -1006,7 +1000,8 @@ SaErrorT create_event_session(struct oa_info *oa)
  * Return values:
  *      NONE
  **/
-void create_oa_connection(struct oa_info *oa,
+void create_oa_connection(struct oa_soap_handler *oa_handler,
+                          struct oa_info *oa,
                           char *user_name,
                           char *password)
 {
@@ -1020,11 +1015,13 @@ void create_oa_connection(struct oa_info *oa,
         }
 
         while (is_oa_accessible == SAHPI_FALSE) {
+                OA_SOAP_CHEK_SHUTDOWN_REQ(oa_handler, NULL, NULL, NULL);
                 /* Check whether the OA is present.
                  * If not, wait till the OA is inserted
                  */
                  is_oa_present = SAHPI_FALSE;
                  while (is_oa_present == SAHPI_FALSE) {
+                	OA_SOAP_CHEK_SHUTDOWN_REQ(oa_handler, NULL, NULL, NULL);
                         g_mutex_lock(oa->mutex);
                         if (oa->oa_status != OA_ABSENT) {
                                 g_mutex_unlock(oa->mutex);
@@ -1151,12 +1148,15 @@ SaErrorT delete_all_inventory_info(struct oh_handler_state *oh_handler)
 
         rpt = oh_get_resource_next(oh_handler->rptcache, SAHPI_FIRST_ENTRY);
         while (rpt) {
-                /* Free the inventory info from inventory RDR */
-                rv = free_inventory_info(oh_handler, rpt->ResourceId);
-                if (rv != SA_OK) {
-                        err("Inventory cleanup failed for resource id %d",
-                            rpt->ResourceId);
+                if (rpt->ResourceCapabilities 
+                    & SAHPI_CAPABILITY_INVENTORY_DATA) {
+                        /* Free the inventory info from inventory RDR */
+                        rv = free_inventory_info(oh_handler, rpt->ResourceId);
+                        if (rv != SA_OK) 
+                                err("Inventory cleanup failed for resource %d",
+                                    rpt->ResourceId);
                 }
+                /* Get the next resource */
                 rpt = oh_get_resource_next(oh_handler->rptcache,
                                            rpt->ResourceId);
         }
@@ -1164,143 +1164,6 @@ SaErrorT delete_all_inventory_info(struct oh_handler_state *oh_handler)
         return SA_OK;
 }
 
-/**
- * populate_event
- *       @oh_handler:  Pointer to openhpi handler
- *       @resource_id: Resource Id
- *       @event:       Pointer to event structure
- *
- * Purpose:
- *      Gets the rpt entry and RDR from plugin RPTable for
- *      the resource. Creates the hotswap event and pushes
- *      the event to openhpi infrastructure
- *
- * Detailed Description: NA
- *
- * Return values:
- *      SA_OK                     - on success.
- *      SA_ERR_HPI_OUT_OF_MEMORY  - on out of memory
- *      SA_ERR_HPI_INVALID_PARAMS - on wrong parameters
- *      SA_ERR_HPI_INTERNAL_ERROR - on failure.
- **/
-SaErrorT populate_event(struct oh_handler_state *oh_handler,
-                        SaHpiResourceIdT resource_id,
-                        struct oh_event *event)
-{
-        SaHpiRptEntryT *rpt = NULL;
-        SaHpiRdrT *temp, *rdr = NULL;
-
-        if (oh_handler == NULL || event == NULL) {
-                err("Invalid parameters");
-                return SA_ERR_HPI_INVALID_PARAMS;
-        }
-
-        rpt = oh_get_resource_by_id(oh_handler->rptcache, resource_id);
-
-        memset(event, 0, sizeof(struct oh_event));
-        event->event.Source = rpt->ResourceId;
-        oh_gettimeofday(&event->event.Timestamp);
-        event->event.Severity = rpt->ResourceSeverity;
-        event->resource = *rpt;
-        event->hid = oh_handler->hid;
-
-        /* Add all RDRs of this RPT entry */
-        rdr = oh_get_rdr_next(oh_handler->rptcache, rpt->ResourceId,
-                                    SAHPI_FIRST_ENTRY);
-        while (rdr) {
-                temp = g_memdup(rdr, sizeof(SaHpiRdrT));
-                if (temp == NULL) {
-                        err("Out of memory");
-                        return SA_ERR_HPI_OUT_OF_MEMORY;
-                }
-                event->rdrs = g_slist_append(event->rdrs, temp);
-                rdr = oh_get_rdr_next(oh_handler->rptcache, rpt->ResourceId,
-                                      rdr->RecordId);
-        }
-
-        return SA_OK;
-}
-
-/**
- * push_discovered_resource_events
- *       @oh_handler: Pointer to openhpi handler
- *
- * Purpose:
- *      Gets all the rpt entry and RDR from plugin RPTable.
- *      Creates the resource/hotswap event and pushes
- *      the events to openhpi infrastructure
- *
- * Detailed Description: NA
- *
- * Return values:
- *      SA_OK                     - on success.
- *      SA_ERR_HPI_OUT_OF_MEMORY  - on out of memory
- *      SA_ERR_HPI_INVALID_PARAMS - on wrong parameters
- *      SA_ERR_HPI_INTERNAL_ERROR - on failure.
- **/
-SaErrorT push_discovered_resource_events(struct oh_handler_state *oh_handler)
-{
-        SaErrorT rv = SA_OK;
-        SaHpiRptEntryT *rpt = NULL;
-        struct oh_event event;
-        struct oa_soap_hotswap_state *hotswap_state = NULL;
-
-        if (oh_handler == NULL) {
-                err("Invalid parameter");
-                return SA_ERR_HPI_INVALID_PARAMS;
-        }
-
-        rpt = oh_get_resource_next(oh_handler->rptcache, SAHPI_FIRST_ENTRY);
-        while (rpt) {
-                rv = populate_event(oh_handler, rpt->ResourceId, &event);
-
-                /* Check whether the resource has hotswap capability */
-                if (event.resource.ResourceCapabilities &
-                        SAHPI_CAPABILITY_MANAGED_HOTSWAP) {
-                        /* Get the hotswap state and fill the current
-                         * hotswap state
-                         */
-                        hotswap_state = (struct oa_soap_hotswap_state *)
-                                oh_get_resource_data(oh_handler->rptcache,
-                                                     event.resource.ResourceId);
-                        if (hotswap_state == NULL) {
-                                err("Failed to get server hotswap state");
-                                return SA_ERR_HPI_INTERNAL_ERROR;
-                        }
-                        event.event.EventType = SAHPI_ET_HOTSWAP;
-                        event.event.EventDataUnion.HotSwapEvent.HotSwapState =
-                                hotswap_state->currentHsState;
-                        event.event.EventDataUnion.HotSwapEvent.
-                                CauseOfStateChange = SAHPI_HS_CAUSE_UNKNOWN;
-                } else if (event.resource.ResourceCapabilities &
-                                SAHPI_CAPABILITY_FRU) {
-                        /* The resource is FRU, but does not have hotswap
-                         * capability Fill the current hotswap state as ACTIVE.
-                         */
-                        event.event.EventType = SAHPI_ET_HOTSWAP;
-                        event.event.EventDataUnion.HotSwapEvent.HotSwapState =
-                                SAHPI_HS_STATE_ACTIVE;
-                        event.event.EventDataUnion.HotSwapEvent.
-                                CauseOfStateChange = SAHPI_HS_CAUSE_UNKNOWN;
-                } else {
-                        /* The resource does not have FRU and hotswap
-                         * capabilities. Raise the resrouce event.
-                         */
-                        event.event.EventType = SAHPI_ET_RESOURCE;
-                        event.event.EventDataUnion.ResourceEvent.
-                                ResourceEventType = SAHPI_RESE_RESOURCE_ADDED;
-                }
-                /* Push the event to OpenHPI */
-                oh_evt_queue_push(oh_handler->eventq,
-                                  copy_oa_soap_event(&event));
-
-                rpt = oh_get_resource_next(oh_handler->rptcache,
-                                           rpt->ResourceId);
-        } /* End of while loop */
-
-        return SA_OK;
-}
-
 /**
  * cleanup_plugin_rptable
  *      @oh_handler: Pointer to the plugin handler
@@ -1316,17 +1179,26 @@ SaErrorT push_discovered_resource_events(struct oh_handler_state *oh_handler)
 void cleanup_plugin_rptable(struct oh_handler_state *oh_handler)
 {
         SaErrorT rv = SA_OK;
+        struct oa_soap_handler *oa_handler = NULL;
 
         if (oh_handler == NULL) {
                 err("Invalid parameter");
                 return;
         }
 
+        oa_handler = (struct oa_soap_handler *) oh_handler->data;
+        if(oa_handler == NULL) {
+                err("Invalid parameter");
+                return;
+        }
+
         rv = delete_all_inventory_info(oh_handler);
         if (rv != SA_OK) {
                 err("Deleting all inventory information failed");
         }
 
+        release_oa_soap_resources(oa_handler);
+
         rv = oh_flush_rpt(oh_handler->rptcache);
         if (rv != SA_OK) {
                 err("Plugin RPTable flush failed");
@@ -1352,59 +1224,96 @@ void release_oa_soap_resources(struct oa_soap_handler *oa_handler)
 {
         SaHpiInt32T i;
 
-        /* Release memory of blade presence and blade serial number array */
+        /* Release memory of blade presence, resource id and blade
+         * serial number arrays
+         */
         if (oa_handler->oa_soap_resources.server.presence != NULL) {
                 g_free(oa_handler->oa_soap_resources.server.presence);
         }
-        for (i = 0; i < oa_handler->oa_soap_resources.server.max_bays; i++) {
-                if (oa_handler->oa_soap_resources.server.serial_number[i] !=
-                    NULL)
+        if (oa_handler->oa_soap_resources.server.resource_id != NULL) {
+                g_free(oa_handler->oa_soap_resources.server.resource_id);
+        }
+	if(oa_handler->oa_soap_resources.server.serial_number != NULL) {
+	    for (i = 0; i < oa_handler->oa_soap_resources.server.max_bays; i++)
+	    {
+		if (oa_handler->oa_soap_resources.server.serial_number[i] !=
+                    NULL) {
                         g_free(oa_handler->oa_soap_resources.server.
                                serial_number[i]);
-        }
-        g_free(oa_handler->oa_soap_resources.server.serial_number);
+		}
+            }
+            g_free(oa_handler->oa_soap_resources.server.serial_number);
+	}
 
         /* Release memory of interconnect presence and serial number array */
         if (oa_handler->oa_soap_resources.interconnect.presence != NULL) {
                 g_free(oa_handler->oa_soap_resources.interconnect.presence);
         }
-        for (i = 0; i < oa_handler->oa_soap_resources.interconnect.max_bays;
+        if (oa_handler->oa_soap_resources.interconnect.resource_id != NULL) {
+                g_free(oa_handler->oa_soap_resources.interconnect.resource_id);
+        }
+	if(oa_handler->oa_soap_resources.interconnect.serial_number != NULL) {
+            for (i = 0; i < oa_handler->oa_soap_resources.interconnect.max_bays;
              i++) {
                 if (oa_handler->oa_soap_resources.interconnect.
-                    serial_number[i] != NULL)
+                    serial_number[i] != NULL) {
                         g_free(oa_handler->oa_soap_resources.interconnect.
                                serial_number[i]);
-        }
-        g_free(oa_handler->oa_soap_resources.interconnect.serial_number);
+		}
+            }
+            g_free(oa_handler->oa_soap_resources.interconnect.serial_number);
+	}
 
         /* Release memory of OA presence and serial number array */
         if (oa_handler->oa_soap_resources.oa.presence != NULL) {
                 g_free(oa_handler->oa_soap_resources.oa.presence);
         }
-        for (i = 0; i < oa_handler->oa_soap_resources.oa.max_bays; i++) {
-                if (oa_handler->oa_soap_resources.oa.serial_number[i] != NULL)
+        if (oa_handler->oa_soap_resources.oa.resource_id != NULL) {
+                g_free(oa_handler->oa_soap_resources.oa.resource_id);
+        }
+	if(oa_handler->oa_soap_resources.oa.serial_number != NULL) {
+            for (i = 0; i < oa_handler->oa_soap_resources.oa.max_bays; i++) {
+                if (oa_handler->oa_soap_resources.oa.serial_number[i] != NULL) {
                         g_free(oa_handler->oa_soap_resources.oa.
                                serial_number[i]);
-        }
-        g_free(oa_handler->oa_soap_resources.oa.serial_number);
+		}
+            }
+            g_free(oa_handler->oa_soap_resources.oa.serial_number);
+	}
 
-        /* Release memory of fan presence. Since fans does not have serial
-         * numbers, hence serial numbers array is not created for fans
+        /* Release memory of fan presence.  Since fans do not have serial
+         * numbers, a serial numbers array does not need to be released.
          */
-        if (oa_handler->oa_soap_resources.fan.presence != NULL)
+        if (oa_handler->oa_soap_resources.fan.presence != NULL) {
                 g_free(oa_handler->oa_soap_resources.fan.presence);
+        }
+        if (oa_handler->oa_soap_resources.fan.resource_id != NULL) {
+                g_free(oa_handler->oa_soap_resources.fan.resource_id);
+        }
+
+        /* Release memory of fan zone resource id */
+        if (oa_handler->oa_soap_resources.fan_zone.resource_id != NULL) {
+                g_free(oa_handler->oa_soap_resources.fan_zone.resource_id);
+        }
 
         /* Release memory of power supply presence and serial number array */
         if (oa_handler->oa_soap_resources.ps_unit.presence !=NULL) {
                 g_free(oa_handler->oa_soap_resources.ps_unit.presence);
         }
-        for (i = 0; i < oa_handler->oa_soap_resources.ps_unit.max_bays; i++) {
+        if (oa_handler->oa_soap_resources.ps_unit.resource_id !=NULL) {
+                g_free(oa_handler->oa_soap_resources.ps_unit.resource_id);
+        }
+	if(oa_handler->oa_soap_resources.ps_unit.serial_number != NULL) {
+            for (i = 0; i < oa_handler->oa_soap_resources.ps_unit.max_bays; i++)
+	    {
                 if (oa_handler->oa_soap_resources.ps_unit.serial_number[i]
-                    != NULL)
+                    != NULL) {
                         g_free(oa_handler->oa_soap_resources.
                                 ps_unit.serial_number[i]);
-        }
-        g_free(oa_handler->oa_soap_resources.ps_unit.serial_number);
+		}
+            }
+            g_free(oa_handler->oa_soap_resources.ps_unit.serial_number);
+	}
 }
 
 /**
@@ -1459,7 +1368,6 @@ SaErrorT update_oa_info(struct oh_handler_state *oh_handler,
                         struct oaInfo *response,
                         SaHpiResourceIdT resource_id)
 {
-        struct oa_soap_handler *oa_handler;
         SaHpiRptEntryT *rpt = NULL;
         SaHpiFloat64T fm_version;
         SaHpiInt32T major;
@@ -1469,12 +1377,6 @@ SaErrorT update_oa_info(struct oh_handler_state *oh_handler,
                 return SA_ERR_HPI_INVALID_PARAMS;
         }
 
-        /* Copy the serial number of the OA to serial_number array */
-        oa_handler = (struct oa_soap_handler *) oh_handler->data;
-        strcpy(oa_handler->oa_soap_resources.oa.
-               serial_number[response->bayNumber - 1],
-               response->serialNumber);
-
         rpt = oh_get_resource_by_id(oh_handler->rptcache, resource_id);
         if (rpt == NULL) {
                 err("OA rpt is not present");
@@ -1537,3 +1439,44 @@ SaErrorT convert_lower_to_upper(char *src,
 
         return SA_OK;
 }
+
+/**
+ * update_reseource_status()
+ *      @res_status     pointer to resource_status_t
+ *      @index          index into the resource info fields in res_status
+ *      @serial_number  serial_number string to be copied into res_status
+ *      @resource_id    resource id to be updated to res_status
+ *      @presence       presence status
+ *
+ *      Description:
+ *      This routine updates the resource status entry with passed in
+ *      serial_number, resource_id, and presence.  This routine should be
+ *      called to set and reset the resource status fields that change
+ *      when a a resource gets added and removed.
+ *
+ *      Return value: none
+**/
+void oa_soap_update_resource_status(resource_status_t *res_status,
+                                    SaHpiInt32T index,
+                                    char *serial_number,
+                                    SaHpiResourceIdT resource_id,
+                                    resource_presence_status_t presence)
+{
+        if (index <= 0) {
+                err("Invalid index value %d - returning without update\n",
+                    index);
+                return;
+        }
+        if (serial_number != NULL) {
+                size_t len;
+
+                len = strlen(serial_number);
+                strncpy(res_status->serial_number[index-1], serial_number, len);
+                res_status->serial_number[index-1][len] = '\0';
+        }
+        res_status->resource_id[index-1] = resource_id;
+        res_status->presence[index-1] = presence;
+
+        return;
+}
+
